@@ -4,14 +4,17 @@ use strict;
 use warnings;
 
 use AnyEvent::Net::MPD;
+
+use Log::Any::Adapter;
 Log::Any::Adapter->set( 'Stderr', log_level => 'trace' );
-my $log = Log::Any->get_logger;
 
 my $mpd = AnyEvent::Net::MPD->new(
   maybe host => $ARGV[0],
   auto_connect => 1,
 );
 
+$mpd->on( error => sub { $mpd->noidle });
+
 foreach my $event (qw(
     database udpate stored_playlist playlist player
     mixer output sticker subscription message
